<template>
	<ywDialog
		v-model="dialogIsShow"
		:headerIcon="dialogHeaderIcon"
		:title="dialogTitle"
		width="470"
		@dlgClosed="closeDialog"
		@submit="submitFormValue"
	>
		<el-form :model="dialogFormValue" ref="dialogFormRef" :rules="dialogFormRules" label-width="116">
			<el-form-item label="工作流名称" prop="title">
				<el-input v-model="dialogFormValue.title"></el-input>
			</el-form-item>

			<el-form-item label="工作流提示" prop="prompt">
				<el-input v-model="dialogFormValue.prompt"></el-input>
			</el-form-item>
			<el-form-item label="内部调用" prop="inner_call">
				<el-select class="w100" placeholder="请选择" filterable v-model="dialogFormValue.inner_call" :disabled="isEditDialog">
					<el-option
						v-for="(item, index) in Object.keys(supervisorInnerCallMap)"
						:key="index + ''"
						:value="item"
						:label="supervisorInnerCallMap[item]"
					></el-option>
				</el-select>
			</el-form-item>
		</el-form>
	</ywDialog>
</template>

<script setup lang="ts">
import type { FormInstance, FormRules } from 'element-plus';
import { ElMessage } from 'element-plus';
import { computed, ref, watch } from 'vue';
import { add_workflow_agent, update_workflow_agent } from '/@/api/workflow/index';
import ywDialog from '/@/components/dialog/yw-dialog.vue';
import { deepClone } from '/@/utils/other';
import { supervisorInnerCallMap } from '/@/views/project/yw/dataManage/types';
import { SupervisorPublished } from '/@/views/project/yw/lowCode/sqlAmis/types';
const props = defineProps(['item', 'currentListID']);
const emit = defineEmits(['update', 'insert']);
//#region ====================== 增加、修改记录操作, dialog init======================
const isEditDialog = ref(false);
const dialogTitle = computed(() => {
	return isEditDialog.value ? '修改工作流' : '添加工作流';
});
const dialogHeaderIcon = computed(() => {
	return isEditDialog.value ? 'ele-Edit' : 'ele-Plus';
});
const dialogFormValue = ref(null);
const dialogIsShow = defineModel({
	type: Boolean,
});
const dialogFormRef = ref<FormInstance>(null);

const dialogFormRules = ref<FormRules>({
	title: [{ required: true, message: '请输入工作流名称', trigger: 'blur' }],
	prompt: [{ required: true, message: '请输入工作流提示', trigger: 'blur' }],
	inner_call: [{ required: true, message: '请选择内部调用', trigger: 'change' }],
});
const openOperateDialog = (row?) => {
	if (row) {
		isEditDialog.value = true;
		const { title, inner_call, id, create_user,prompt } = row;
		dialogFormValue.value = deepClone({ title, inner_call, id, create_user, prompt });
	} else {
		isEditDialog.value = false;
		dialogFormValue.value = { title: null, prompt: null, inner_call: null };
	}
};
const closeDialog = () => {
	dialogIsShow.value = false;
	dialogFormRef.value.clearValidate();
};

const submitFormValue = async () => {
	const valid = await dialogFormRef.value.validate().catch(() => {});
	if (!valid) return;
	const currentTime = new Date().toLocaleString();
	const sendForm = { ...dialogFormValue.value, group_id: props.currentListID };
	if (isEditDialog.value) {
		const res = await update_workflow_agent({
			agent_id: props.item.id,
			title: sendForm.title,
			prompt: dialogFormValue.value.prompt,
		});

		emit('update', { ...dialogFormValue.value });
		closeDialog();
		ElMessage.success('修改工作流成功');
	} else {
		const res = await add_workflow_agent(sendForm);
		const newData = {
			...dialogFormValue.value,
			id: res.agent_id,
			create_user: '',
			create_time: currentTime,
			note: null,
			agent_group: props.currentListID,
			published: SupervisorPublished.N,
		};
		emit('insert', newData);
		closeDialog();
		ElMessage.success('添加工作流成功');
	}
};
//#endregion

watch(
	() => dialogIsShow.value,
	(val) => {
		if (!val) return;
		openOperateDialog(props.item);
	}
);
</script>
<style scoped lang="scss"></style>
